# pc4g
RESTful api client to a GIG based cloud.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import pc4g 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pc4g
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import pc4g
from pc4g.rest import ApiException
from pprint import pprint

# Configure API key authorization: Bearer
configuration = pc4g.Configuration("https://example.portal.cloud/api/1")
configuration.api_key['Authorization'] = 'YOUR_API_KEY'

configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = pc4g.CustomersApi(pc4g.ApiClient(configuration))
customer_id = 'CUSTOMER_ID' # str | 


try:
    api_instance.list_cloudspaces(customer_id)
except ApiException as e:
    print("Exception when calling CustomersApi->list_cloudspaces: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to the base URL of pc4g.Configuration(HOST)

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**change_invoice_payment_status**](docs/AdminApi.md#change_invoice_payment_status) | **PUT** /admin/invoices/{invoice_id}/status | 
*AdminApi* | [**create_vco_notification**](docs/AdminApi.md#create_vco_notification) | **POST** /admin/email-notifications | 
*AdminApi* | [**delete_invoice**](docs/AdminApi.md#delete_invoice) | **DELETE** /admin/invoices/{invoice_id} | 
*AdminApi* | [**delete_vco_notification**](docs/AdminApi.md#delete_vco_notification) | **DELETE** /admin/email-notification/{notification_id} | 
*AdminApi* | [**delete_vco_to_customer_prices**](docs/AdminApi.md#delete_vco_to_customer_prices) | **DELETE** /admin/prices/{customer_id} | 
*AdminApi* | [**edit_notification_forwarding**](docs/AdminApi.md#edit_notification_forwarding) | **PUT** /admin/email-notification-forwarding | 
*AdminApi* | [**generate_invoices**](docs/AdminApi.md#generate_invoices) | **POST** /admin/invoices | 
*AdminApi* | [**get_acceptable_use_policy**](docs/AdminApi.md#get_acceptable_use_policy) | **GET** /admin/legal/acceptable_use_policy | 
*AdminApi* | [**get_chat_config**](docs/AdminApi.md#get_chat_config) | **GET** /admin/chat | 
*AdminApi* | [**get_color_scheme**](docs/AdminApi.md#get_color_scheme) | **GET** /admin/branding/color-scheme | 
*AdminApi* | [**get_cookie_policy**](docs/AdminApi.md#get_cookie_policy) | **GET** /admin/legal/cookie_policy | 
*AdminApi* | [**get_demo_user**](docs/AdminApi.md#get_demo_user) | **GET** /admin/demo-user | 
*AdminApi* | [**get_invoice**](docs/AdminApi.md#get_invoice) | **GET** /admin/invoices/{invoice_id} | 
*AdminApi* | [**get_invoice_legal_terms**](docs/AdminApi.md#get_invoice_legal_terms) | **GET** /admin/invoices/legal-terms | 
*AdminApi* | [**get_invoice_numbering_format**](docs/AdminApi.md#get_invoice_numbering_format) | **GET** /admin/invoices/numbering-format | 
*AdminApi* | [**get_invoice_payment_terms**](docs/AdminApi.md#get_invoice_payment_terms) | **GET** /admin/invoices/payment-terms | 
*AdminApi* | [**get_invoice_pdf**](docs/AdminApi.md#get_invoice_pdf) | **GET** /admin/invoices/{invoice_id}/pdf | 
*AdminApi* | [**get_latest_sequence_number**](docs/AdminApi.md#get_latest_sequence_number) | **GET** /admin/invoices/{invoice_id}/sequence-number | 
*AdminApi* | [**get_legal_documents**](docs/AdminApi.md#get_legal_documents) | **GET** /admin/legal | 
*AdminApi* | [**get_logo**](docs/AdminApi.md#get_logo) | **GET** /admin/branding/logo | 
*AdminApi* | [**get_naming**](docs/AdminApi.md#get_naming) | **GET** /admin/naming | 
*AdminApi* | [**get_notification_forwarding**](docs/AdminApi.md#get_notification_forwarding) | **GET** /admin/email-notification-forwarding | 
*AdminApi* | [**get_payment_config**](docs/AdminApi.md#get_payment_config) | **GET** /admin/payment-config | 
*AdminApi* | [**get_privacy_policy**](docs/AdminApi.md#get_privacy_policy) | **GET** /admin/legal/privacy_policy | 
*AdminApi* | [**get_terms_conditions**](docs/AdminApi.md#get_terms_conditions) | **GET** /admin/legal/terms_and_conditions | 
*AdminApi* | [**get_v_website**](docs/AdminApi.md#get_v_website) | **GET** /admin/branding/vco-website | 
*AdminApi* | [**get_vco_buying_prices**](docs/AdminApi.md#get_vco_buying_prices) | **GET** /admin/buying-prices | 
*AdminApi* | [**get_vco_notification**](docs/AdminApi.md#get_vco_notification) | **GET** /admin/email-notification/{notification_id} | 
*AdminApi* | [**get_vco_settings**](docs/AdminApi.md#get_vco_settings) | **GET** /admin/settings | 
*AdminApi* | [**get_vco_timezone**](docs/AdminApi.md#get_vco_timezone) | **GET** /admin/timezone | 
*AdminApi* | [**get_vco_to_customer_prices**](docs/AdminApi.md#get_vco_to_customer_prices) | **GET** /admin/prices/{customer_id} | 
*AdminApi* | [**get_vco_to_customer_standard_prices**](docs/AdminApi.md#get_vco_to_customer_standard_prices) | **GET** /admin/prices | 
*AdminApi* | [**list_invoices**](docs/AdminApi.md#list_invoices) | **GET** /admin/invoices | 
*AdminApi* | [**list_notification_utilities**](docs/AdminApi.md#list_notification_utilities) | **GET** /admin/email-notification/utilities | 
*AdminApi* | [**list_vco_notifications**](docs/AdminApi.md#list_vco_notifications) | **GET** /admin/email-notifications | 
*AdminApi* | [**pay_invoice_with_card**](docs/AdminApi.md#pay_invoice_with_card) | **POST** /admin/invoices/{invoice_id}/pay-with-card | 
*AdminApi* | [**put_vco_settings**](docs/AdminApi.md#put_vco_settings) | **PUT** /admin/settings | 
*AdminApi* | [**regenerate_invoice**](docs/AdminApi.md#regenerate_invoice) | **POST** /admin/invoices/{invoice_id} | 
*AdminApi* | [**send_invoice**](docs/AdminApi.md#send_invoice) | **POST** /admin/invoices/{invoice_id}/send | 
*AdminApi* | [**send_vco_notification**](docs/AdminApi.md#send_vco_notification) | **PUT** /admin/email-notification/{notification_id}/send | 
*AdminApi* | [**send_vco_test_notification**](docs/AdminApi.md#send_vco_test_notification) | **PUT** /admin/email-notification/{notification_id}/send-test | 
*AdminApi* | [**set_chat_config**](docs/AdminApi.md#set_chat_config) | **PUT** /admin/chat | 
*AdminApi* | [**set_color_scheme**](docs/AdminApi.md#set_color_scheme) | **POST** /admin/branding/color-scheme | 
*AdminApi* | [**set_demo_user**](docs/AdminApi.md#set_demo_user) | **POST** /admin/demo-user | 
*AdminApi* | [**set_description**](docs/AdminApi.md#set_description) | **POST** /admin/branding/description | 
*AdminApi* | [**set_invoice**](docs/AdminApi.md#set_invoice) | **PUT** /admin/invoices/{invoice_id} | 
*AdminApi* | [**set_legal_documents**](docs/AdminApi.md#set_legal_documents) | **POST** /admin/legal | 
*AdminApi* | [**set_logo**](docs/AdminApi.md#set_logo) | **POST** /admin/branding/logo | 
*AdminApi* | [**set_payment_config**](docs/AdminApi.md#set_payment_config) | **PUT** /admin/payment-config | 
*AdminApi* | [**set_vco_to_customer_prices**](docs/AdminApi.md#set_vco_to_customer_prices) | **PUT** /admin/prices/{customer_id} | 
*AdminApi* | [**set_vco_to_customer_standard_prices**](docs/AdminApi.md#set_vco_to_customer_standard_prices) | **PUT** /admin/prices | 
*AdminApi* | [**set_website**](docs/AdminApi.md#set_website) | **PUT** /admin/branding/vco-website | 
*AdminApi* | [**unset_demo_user**](docs/AdminApi.md#unset_demo_user) | **DELETE** /admin/demo-user | 
*AdminApi* | [**update_invoice_legal_terms**](docs/AdminApi.md#update_invoice_legal_terms) | **PUT** /admin/invoices/legal-terms | 
*AdminApi* | [**update_invoice_numbering_format**](docs/AdminApi.md#update_invoice_numbering_format) | **PUT** /admin/invoices/numbering-format | 
*AdminApi* | [**update_invoice_payment_terms**](docs/AdminApi.md#update_invoice_payment_terms) | **PUT** /admin/invoices/payment-terms | 
*AdminApi* | [**update_naming**](docs/AdminApi.md#update_naming) | **PUT** /admin/naming | 
*AdminApi* | [**update_vco_notification**](docs/AdminApi.md#update_vco_notification) | **PUT** /admin/email-notification/{notification_id} | 
*AlphaApi* | [**add_customer_card**](docs/AlphaApi.md#add_customer_card) | **POST** /alpha/customer/{customer_id}/cards | 
*AlphaApi* | [**add_host_to_server_pool**](docs/AlphaApi.md#add_host_to_server_pool) | **POST** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/server-pools/{serverpool_id}/hosts | 
*AlphaApi* | [**create_cloudspaces_server_pool**](docs/AlphaApi.md#create_cloudspaces_server_pool) | **POST** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/server-pools | 
*AlphaApi* | [**create_load_balancer**](docs/AlphaApi.md#create_load_balancer) | **POST** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/load-balancers | 
*AlphaApi* | [**create_reverse_proxy**](docs/AlphaApi.md#create_reverse_proxy) | **POST** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/reverse-proxies | 
*AlphaApi* | [**delete_customer_card**](docs/AlphaApi.md#delete_customer_card) | **DELETE** /alpha/customer/{customer_id}/cards/{card_id} | 
*AlphaApi* | [**delete_load_balancer**](docs/AlphaApi.md#delete_load_balancer) | **DELETE** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/load-balancers/{loadbalancer_id} | 
*AlphaApi* | [**delete_reverse_proxy**](docs/AlphaApi.md#delete_reverse_proxy) | **DELETE** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/reverse-proxies/{reverseproxy_id} | 
*AlphaApi* | [**delete_server_pool**](docs/AlphaApi.md#delete_server_pool) | **DELETE** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/server-pools/{serverpool_id} | 
*AlphaApi* | [**generate_traefik_config**](docs/AlphaApi.md#generate_traefik_config) | **GET** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/traefik | 
*AlphaApi* | [**get_customer_card**](docs/AlphaApi.md#get_customer_card) | **GET** /alpha/customer/{customer_id}/cards/{card_id} | 
*AlphaApi* | [**get_reverse_proxy_info**](docs/AlphaApi.md#get_reverse_proxy_info) | **GET** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/reverse-proxies/{reverseproxy_id} | 
*AlphaApi* | [**get_server_pool_info**](docs/AlphaApi.md#get_server_pool_info) | **GET** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/server-pools/{serverpool_id} | 
*AlphaApi* | [**list_cloudspaces_reverse_proxies**](docs/AlphaApi.md#list_cloudspaces_reverse_proxies) | **GET** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/reverse-proxies | 
*AlphaApi* | [**list_cloudspaces_server_pools**](docs/AlphaApi.md#list_cloudspaces_server_pools) | **GET** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/server-pools | 
*AlphaApi* | [**list_customer_cards**](docs/AlphaApi.md#list_customer_cards) | **GET** /alpha/customer/{customer_id}/cards | 
*AlphaApi* | [**list_load_balancers**](docs/AlphaApi.md#list_load_balancers) | **GET** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/load-balancers | 
*AlphaApi* | [**list_server_pool_hosts**](docs/AlphaApi.md#list_server_pool_hosts) | **GET** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/server-pools/{serverpool_id}/hosts | 
*AlphaApi* | [**remove_host_from_server_pool**](docs/AlphaApi.md#remove_host_from_server_pool) | **DELETE** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/server-pools/{serverpool_id}/hosts/{host_id} | 
*AlphaApi* | [**renew_certificate**](docs/AlphaApi.md#renew_certificate) | **POST** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/reverse-proxies/{reverseproxy_id}/renew-certificate | 
*AlphaApi* | [**set_customer_card_as_default**](docs/AlphaApi.md#set_customer_card_as_default) | **PUT** /alpha/customer/{customer_id}/cards/{card_id} | 
*AlphaApi* | [**show_load_balancer_info**](docs/AlphaApi.md#show_load_balancer_info) | **GET** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/load-balancers/{loadbalancer_id} | 
*AlphaApi* | [**update_load_balancer_info**](docs/AlphaApi.md#update_load_balancer_info) | **PUT** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/load-balancers/{loadbalancer_id} | 
*AlphaApi* | [**update_reverse_proxy_info**](docs/AlphaApi.md#update_reverse_proxy_info) | **PUT** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/reverse-proxies/{reverseproxy_id} | 
*AlphaApi* | [**update_server_pool_info**](docs/AlphaApi.md#update_server_pool_info) | **PUT** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/server-pools/{serverpool_id} | 
*AlphaApi* | [**update_traefik_config**](docs/AlphaApi.md#update_traefik_config) | **PUT** /alpha/customers/{customer_id}/cloudspaces/{cloudspace_id}/ingress/traefik | 
*CustomersApi* | [**add_cloudspace_anti_affinity_group**](docs/CustomersApi.md#add_cloudspace_anti_affinity_group) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/anti-affinity-groups | 
*CustomersApi* | [**add_cloudspace_external_network**](docs/CustomersApi.md#add_cloudspace_external_network) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/external-network | 
*CustomersApi* | [**add_cloudspace_network_route**](docs/CustomersApi.md#add_cloudspace_network_route) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/routes | 
*CustomersApi* | [**add_customer_location**](docs/CustomersApi.md#add_customer_location) | **POST** /customers/{customer_id}/locations | 
*CustomersApi* | [**add_remote_cloudspace**](docs/CustomersApi.md#add_remote_cloudspace) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/connected-cloudspaces | 
*CustomersApi* | [**add_support_access**](docs/CustomersApi.md#add_support_access) | **POST** /customers/{customer_id}/support-access | 
*CustomersApi* | [**add_virtual_machine_anti_affinity_groups**](docs/CustomersApi.md#add_virtual_machine_anti_affinity_groups) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/anti-affinity-groups/{group_id}/vms | 
*CustomersApi* | [**attach_disk_virtual_machine**](docs/CustomersApi.md#attach_disk_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/disks | 
*CustomersApi* | [**attach_external_networks_virtual_machine**](docs/CustomersApi.md#attach_external_networks_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/external-nics | 
*CustomersApi* | [**attach_virtual_machine_cdrom**](docs/CustomersApi.md#attach_virtual_machine_cdrom) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/cdrom-images | 
*CustomersApi* | [**change_agent_status**](docs/CustomersApi.md#change_agent_status) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/agent | 
*CustomersApi* | [**clone_disk_snapshot**](docs/CustomersApi.md#clone_disk_snapshot) | **POST** /customers/{customer_id}/locations/{location}/disks/{disk_id}/snapshots/{snapshot_id}/clone | 
*CustomersApi* | [**compliance_scan**](docs/CustomersApi.md#compliance_scan) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/compliance-scan | 
*CustomersApi* | [**connect_objectspace**](docs/CustomersApi.md#connect_objectspace) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/objectspaces | 
*CustomersApi* | [**create_bucket**](docs/CustomersApi.md#create_bucket) | **POST** /customers/{customer_id}/objectspaces/{objectspace_id}/buckets/{bucket_id} | 
*CustomersApi* | [**create_cloudspace**](docs/CustomersApi.md#create_cloudspace) | **POST** /customers/{customer_id}/cloudspaces | 
*CustomersApi* | [**create_cloudspace_note**](docs/CustomersApi.md#create_cloudspace_note) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/notes | 
*CustomersApi* | [**create_customer**](docs/CustomersApi.md#create_customer) | **POST** /customers | 
*CustomersApi* | [**create_customer_cdrom_image**](docs/CustomersApi.md#create_customer_cdrom_image) | **POST** /customers/{customer_id}/locations/{location}/cdrom-images | 
*CustomersApi* | [**create_customer_certificate**](docs/CustomersApi.md#create_customer_certificate) | **POST** /customers/{customer_id}/certificates/ssl | 
*CustomersApi* | [**create_customer_image**](docs/CustomersApi.md#create_customer_image) | **POST** /customers/{customer_id}/locations/{location}/vm-images | 
*CustomersApi* | [**create_disk**](docs/CustomersApi.md#create_disk) | **POST** /customers/{customer_id}/locations/{location}/disks | 
*CustomersApi* | [**create_disk_note**](docs/CustomersApi.md#create_disk_note) | **POST** /customers/{customer_id}/locations/{location}/disks/{disk_id}/notes | 
*CustomersApi* | [**create_objectspace**](docs/CustomersApi.md#create_objectspace) | **POST** /customers/{customer_id}/objectspaces | 
*CustomersApi* | [**create_objectspace_note**](docs/CustomersApi.md#create_objectspace_note) | **POST** /customers/{customer_id}/objectspaces/{objectspace_id}/notes | 
*CustomersApi* | [**create_portforward**](docs/CustomersApi.md#create_portforward) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/portforwards | 
*CustomersApi* | [**create_role**](docs/CustomersApi.md#create_role) | **POST** /customers/{customer_id}/roles | 
*CustomersApi* | [**create_template_from_vm**](docs/CustomersApi.md#create_template_from_vm) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/template | 
*CustomersApi* | [**create_virtual_machine**](docs/CustomersApi.md#create_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms | 
*CustomersApi* | [**create_virtual_machine_from_s3**](docs/CustomersApi.md#create_virtual_machine_from_s3) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/import-s3 | 
*CustomersApi* | [**create_virtual_machine_note**](docs/CustomersApi.md#create_virtual_machine_note) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/notes | 
*CustomersApi* | [**delete_anti_affinity_group_virtual_machine**](docs/CustomersApi.md#delete_anti_affinity_group_virtual_machine) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/anti-affinity-groups/{group_id}/vms/{vm_id} | 
*CustomersApi* | [**delete_bucket**](docs/CustomersApi.md#delete_bucket) | **DELETE** /customers/{customer_id}/objectspaces/{objectspace_id}/buckets/{bucket_id} | 
*CustomersApi* | [**delete_certificate**](docs/CustomersApi.md#delete_certificate) | **DELETE** /customers/{customer_id}/certificates/ssl/{domain} | 
*CustomersApi* | [**delete_cloudspace**](docs/CustomersApi.md#delete_cloudspace) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id} | 
*CustomersApi* | [**delete_cloudspace_anti_affinity_group**](docs/CustomersApi.md#delete_cloudspace_anti_affinity_group) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/anti-affinity-groups/{group_id} | 
*CustomersApi* | [**delete_cloudspace_note**](docs/CustomersApi.md#delete_cloudspace_note) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/notes/{note_id} | 
*CustomersApi* | [**delete_cloudspace_proxy_config**](docs/CustomersApi.md#delete_cloudspace_proxy_config) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/proxy-server | 
*CustomersApi* | [**delete_customer**](docs/CustomersApi.md#delete_customer) | **DELETE** /customers/{customer_id} | 
*CustomersApi* | [**delete_customer_cdrom_image**](docs/CustomersApi.md#delete_customer_cdrom_image) | **DELETE** /customers/{customer_id}/locations/{location}/cdrom-images/{cdrom_id} | 
*CustomersApi* | [**delete_customer_image**](docs/CustomersApi.md#delete_customer_image) | **DELETE** /customers/{customer_id}/locations/{location}/vm-images/{image_id} | 
*CustomersApi* | [**delete_disk**](docs/CustomersApi.md#delete_disk) | **DELETE** /customers/{customer_id}/locations/{location}/disks/{disk_id} | 
*CustomersApi* | [**delete_disk_note**](docs/CustomersApi.md#delete_disk_note) | **DELETE** /customers/{customer_id}/locations/{location}/disks/{disk_id}/notes/{note_id} | 
*CustomersApi* | [**delete_disk_snapshot**](docs/CustomersApi.md#delete_disk_snapshot) | **DELETE** /customers/{customer_id}/locations/{location}/disks/{disk_id}/snapshots/{snapshot_id} | 
*CustomersApi* | [**delete_file**](docs/CustomersApi.md#delete_file) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/file | 
*CustomersApi* | [**delete_objectspace**](docs/CustomersApi.md#delete_objectspace) | **DELETE** /customers/{customer_id}/objectspaces/{objectspace_id} | 
*CustomersApi* | [**delete_objectspace_note**](docs/CustomersApi.md#delete_objectspace_note) | **DELETE** /customers/{customer_id}/objectspaces/{objectspace_id}/notes/{note_id} | 
*CustomersApi* | [**delete_portforward**](docs/CustomersApi.md#delete_portforward) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/portforwards/{portforward_id} | 
*CustomersApi* | [**delete_remote_cloudspace_connection**](docs/CustomersApi.md#delete_remote_cloudspace_connection) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/connected-cloudspaces/{connected_cloudspace_id} | 
*CustomersApi* | [**delete_role**](docs/CustomersApi.md#delete_role) | **DELETE** /customers/{customer_id}/roles/{role_id} | 
*CustomersApi* | [**delete_support_access**](docs/CustomersApi.md#delete_support_access) | **DELETE** /customers/{customer_id}/support-access | 
*CustomersApi* | [**delete_virtual_machine**](docs/CustomersApi.md#delete_virtual_machine) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id} | 
*CustomersApi* | [**delete_virtual_machine_note**](docs/CustomersApi.md#delete_virtual_machine_note) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/notes/{note_id} | 
*CustomersApi* | [**detach_disk_virtual_machine**](docs/CustomersApi.md#detach_disk_virtual_machine) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/disks/{disk_id} | 
*CustomersApi* | [**detach_external_networks_virtual_machine**](docs/CustomersApi.md#detach_external_networks_virtual_machine) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/external-nics/{external_ip_address} | 
*CustomersApi* | [**detach_virtual_machine_cdrom**](docs/CustomersApi.md#detach_virtual_machine_cdrom) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/cdrom-images/{cdrom_id} | 
*CustomersApi* | [**disable_cloudspace**](docs/CustomersApi.md#disable_cloudspace) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/disable | 
*CustomersApi* | [**disable_customer**](docs/CustomersApi.md#disable_customer) | **PUT** /customers/{customer_id}/disable | 
*CustomersApi* | [**disconnect_objectspace**](docs/CustomersApi.md#disconnect_objectspace) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/objectspaces | 
*CustomersApi* | [**enable_cloudspace**](docs/CustomersApi.md#enable_cloudspace) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/enable | 
*CustomersApi* | [**enable_customer**](docs/CustomersApi.md#enable_customer) | **PUT** /customers/{customer_id}/enable | 
*CustomersApi* | [**execute_command**](docs/CustomersApi.md#execute_command) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/exec | 
*CustomersApi* | [**export_virtual_machine_to_s3**](docs/CustomersApi.md#export_virtual_machine_to_s3) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/export-s3 | 
*CustomersApi* | [**expose_disk**](docs/CustomersApi.md#expose_disk) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/exposed-disks | 
*CustomersApi* | [**get_agent_status**](docs/CustomersApi.md#get_agent_status) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/agent | 
*CustomersApi* | [**get_bucket**](docs/CustomersApi.md#get_bucket) | **GET** /customers/{customer_id}/objectspaces/{objectspace_id}/buckets/{bucket_id} | 
*CustomersApi* | [**get_certificate_info**](docs/CustomersApi.md#get_certificate_info) | **GET** /customers/{customer_id}/certificates/ssl/{domain} | 
*CustomersApi* | [**get_cloudspace_anti_affinity_group**](docs/CustomersApi.md#get_cloudspace_anti_affinity_group) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/anti-affinity-groups/{group_id} | 
*CustomersApi* | [**get_cloudspace_consumption**](docs/CustomersApi.md#get_cloudspace_consumption) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/consumption | 
*CustomersApi* | [**get_cloudspace_consumption_series**](docs/CustomersApi.md#get_cloudspace_consumption_series) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/consumption/series | 
*CustomersApi* | [**get_cloudspace_default_gateway**](docs/CustomersApi.md#get_cloudspace_default_gateway) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/default-gateway | 
*CustomersApi* | [**get_cloudspace_info**](docs/CustomersApi.md#get_cloudspace_info) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id} | 
*CustomersApi* | [**get_cloudspace_nested_cloudspaces**](docs/CustomersApi.md#get_cloudspace_nested_cloudspaces) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/nested-cloudspaces | 
*CustomersApi* | [**get_cloudspace_notes**](docs/CustomersApi.md#get_cloudspace_notes) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/notes | 
*CustomersApi* | [**get_cloudspace_proxy_config**](docs/CustomersApi.md#get_cloudspace_proxy_config) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/proxy-server | 
*CustomersApi* | [**get_cloudspace_stats**](docs/CustomersApi.md#get_cloudspace_stats) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/statistics | 
*CustomersApi* | [**get_currencies**](docs/CustomersApi.md#get_currencies) | **GET** /customers/currencies | 
*CustomersApi* | [**get_customer_compliance_overview**](docs/CustomersApi.md#get_customer_compliance_overview) | **GET** /customers/compliance | 
*CustomersApi* | [**get_customer_compliance_report**](docs/CustomersApi.md#get_customer_compliance_report) | **GET** /customers/{customer_id}/compliance | 
*CustomersApi* | [**get_customer_compliance_series**](docs/CustomersApi.md#get_customer_compliance_series) | **GET** /customers/{customer_id}/statistics/license-compliance | 
*CustomersApi* | [**get_customer_consumption**](docs/CustomersApi.md#get_customer_consumption) | **GET** /customers/{customer_id}/locations/{location}/consumption | 
*CustomersApi* | [**get_customer_consumption_series**](docs/CustomersApi.md#get_customer_consumption_series) | **GET** /customers/{customer_id}/locations/{location}/consumption/series | 
*CustomersApi* | [**get_customer_info**](docs/CustomersApi.md#get_customer_info) | **GET** /customers/{customer_id} | 
*CustomersApi* | [**get_customer_invoice_pdf**](docs/CustomersApi.md#get_customer_invoice_pdf) | **GET** /customers/{customer_id}/invoices/{invoice_id}/pdf | 
*CustomersApi* | [**get_customer_location_capacity**](docs/CustomersApi.md#get_customer_location_capacity) | **GET** /customers/{customer_id}/locations/{location}/capacity | 
*CustomersApi* | [**get_customer_location_datacenter**](docs/CustomersApi.md#get_customer_location_datacenter) | **GET** /customers/{customer_id}/locations/{location}/datacenter | 
*CustomersApi* | [**get_customer_location_pricing**](docs/CustomersApi.md#get_customer_location_pricing) | **GET** /customers/{customer_id}/locations/{location}/prices | 
*CustomersApi* | [**get_customer_pricing**](docs/CustomersApi.md#get_customer_pricing) | **GET** /customers/{customer_id}/prices | 
*CustomersApi* | [**get_disk_consumption**](docs/CustomersApi.md#get_disk_consumption) | **GET** /customers/{customer_id}/locations/{location}/disks/{disk_id}/consumption | 
*CustomersApi* | [**get_disk_consumption_series**](docs/CustomersApi.md#get_disk_consumption_series) | **GET** /customers/{customer_id}/locations/{location}/disks/{disk_id}/consumption/series | 
*CustomersApi* | [**get_disk_info**](docs/CustomersApi.md#get_disk_info) | **GET** /customers/{customer_id}/locations/{location}/disks/{disk_id} | 
*CustomersApi* | [**get_disk_notes**](docs/CustomersApi.md#get_disk_notes) | **GET** /customers/{customer_id}/locations/{location}/disks/{disk_id}/notes | 
*CustomersApi* | [**get_disk_snapshot**](docs/CustomersApi.md#get_disk_snapshot) | **GET** /customers/{customer_id}/locations/{location}/disks/{disk_id}/snapshots/{snapshot_id} | 
*CustomersApi* | [**get_external_network**](docs/CustomersApi.md#get_external_network) | **GET** /customers/{customer_id}/locations/{location}/external-networks/{external_network_id} | 
*CustomersApi* | [**get_external_networks_virtual_machine**](docs/CustomersApi.md#get_external_networks_virtual_machine) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/external-nics/{external_ip_address} | 
*CustomersApi* | [**get_image**](docs/CustomersApi.md#get_image) | **GET** /customers/{customer_id}/locations/{location}/vm-images/{image_id} | 
*CustomersApi* | [**get_objectspace**](docs/CustomersApi.md#get_objectspace) | **GET** /customers/{customer_id}/objectspaces/{objectspace_id} | 
*CustomersApi* | [**get_objectspace_notes**](docs/CustomersApi.md#get_objectspace_notes) | **GET** /customers/{customer_id}/objectspaces/{objectspace_id}/notes | 
*CustomersApi* | [**get_os_names**](docs/CustomersApi.md#get_os_names) | **GET** /customers/vm-images/os-names | 
*CustomersApi* | [**get_os_types**](docs/CustomersApi.md#get_os_types) | **GET** /customers/vm-images/os-types | 
*CustomersApi* | [**get_portforward**](docs/CustomersApi.md#get_portforward) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/portforwards/{portforward_id} | 
*CustomersApi* | [**get_remote_cloudspace_connection_status**](docs/CustomersApi.md#get_remote_cloudspace_connection_status) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/connected-cloudspaces/{connected_cloudspace_id} | 
*CustomersApi* | [**get_role**](docs/CustomersApi.md#get_role) | **GET** /customers/{customer_id}/roles/{role_id} | 
*CustomersApi* | [**get_support_access**](docs/CustomersApi.md#get_support_access) | **GET** /customers/{customer_id}/support-access | 
*CustomersApi* | [**get_virtual_machine_anti_affinity_groups**](docs/CustomersApi.md#get_virtual_machine_anti_affinity_groups) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/anti-affinity-groups/{group_id}/vms | 
*CustomersApi* | [**get_virtual_machine_console**](docs/CustomersApi.md#get_virtual_machine_console) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/console | 
*CustomersApi* | [**get_virtual_machine_consumption**](docs/CustomersApi.md#get_virtual_machine_consumption) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/consumption | 
*CustomersApi* | [**get_virtual_machine_consumption_series**](docs/CustomersApi.md#get_virtual_machine_consumption_series) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/consumption/series | 
*CustomersApi* | [**get_virtual_machine_info**](docs/CustomersApi.md#get_virtual_machine_info) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id} | 
*CustomersApi* | [**get_virtual_machine_notes**](docs/CustomersApi.md#get_virtual_machine_notes) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/notes | 
*CustomersApi* | [**get_virtual_machine_stats**](docs/CustomersApi.md#get_virtual_machine_stats) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/statistics | 
*CustomersApi* | [**get_vm_price_simulation**](docs/CustomersApi.md#get_vm_price_simulation) | **GET** /customers/{customer_id}/locations/{location}/vm-price-simulation | 
*CustomersApi* | [**get_vmcdrom_info**](docs/CustomersApi.md#get_vmcdrom_info) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/cdrom-images/{cdrom_id} | 
*CustomersApi* | [**list_buckets**](docs/CustomersApi.md#list_buckets) | **GET** /customers/{customer_id}/objectspaces/{objectspace_id}/buckets | 
*CustomersApi* | [**list_cloudspace_anti_affinity_groups**](docs/CustomersApi.md#list_cloudspace_anti_affinity_groups) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/anti-affinity-groups | 
*CustomersApi* | [**list_cloudspace_external_networks**](docs/CustomersApi.md#list_cloudspace_external_networks) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/external-network | 
*CustomersApi* | [**list_cloudspace_network_routes**](docs/CustomersApi.md#list_cloudspace_network_routes) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/routes | 
*CustomersApi* | [**list_cloudspace_objectspaces**](docs/CustomersApi.md#list_cloudspace_objectspaces) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/objectspaces | 
*CustomersApi* | [**list_cloudspace_virtual_machines**](docs/CustomersApi.md#list_cloudspace_virtual_machines) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms | 
*CustomersApi* | [**list_cloudspaces**](docs/CustomersApi.md#list_cloudspaces) | **GET** /customers/{customer_id}/cloudspaces | 
*CustomersApi* | [**list_customer_cdrom_images**](docs/CustomersApi.md#list_customer_cdrom_images) | **GET** /customers/{customer_id}/locations/{location}/cdrom-images | 
*CustomersApi* | [**list_customer_certificates**](docs/CustomersApi.md#list_customer_certificates) | **GET** /customers/{customer_id}/certificates/ssl | 
*CustomersApi* | [**list_customer_images**](docs/CustomersApi.md#list_customer_images) | **GET** /customers/{customer_id}/locations/{location}/vm-images | 
*CustomersApi* | [**list_customer_invoices**](docs/CustomersApi.md#list_customer_invoices) | **GET** /customers/{customer_id}/invoices | 
*CustomersApi* | [**list_customer_locations**](docs/CustomersApi.md#list_customer_locations) | **GET** /customers/{customer_id}/locations | 
*CustomersApi* | [**list_customers**](docs/CustomersApi.md#list_customers) | **GET** /customers | 
*CustomersApi* | [**list_disk_snapshots**](docs/CustomersApi.md#list_disk_snapshots) | **GET** /customers/{customer_id}/locations/{location}/disks/{disk_id}/snapshots | 
*CustomersApi* | [**list_disks**](docs/CustomersApi.md#list_disks) | **GET** /customers/{customer_id}/locations/{location}/disks | 
*CustomersApi* | [**list_disks_virtual_machine**](docs/CustomersApi.md#list_disks_virtual_machine) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/disks | 
*CustomersApi* | [**list_exposed_disks**](docs/CustomersApi.md#list_exposed_disks) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/exposed-disks | 
*CustomersApi* | [**list_external_network_interface_models**](docs/CustomersApi.md#list_external_network_interface_models) | **GET** /customers/external-network-interfaces/models | 
*CustomersApi* | [**list_external_networks**](docs/CustomersApi.md#list_external_networks) | **GET** /customers/{customer_id}/locations/{location}/external-networks | 
*CustomersApi* | [**list_external_networks_virtual_machine**](docs/CustomersApi.md#list_external_networks_virtual_machine) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/external-nics | 
*CustomersApi* | [**list_objectspaces**](docs/CustomersApi.md#list_objectspaces) | **GET** /customers/{customer_id}/objectspaces | 
*CustomersApi* | [**list_portforwards**](docs/CustomersApi.md#list_portforwards) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/portforwards | 
*CustomersApi* | [**list_remote_cloudspace_connections**](docs/CustomersApi.md#list_remote_cloudspace_connections) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/connected-cloudspaces | 
*CustomersApi* | [**list_role_grants**](docs/CustomersApi.md#list_role_grants) | **GET** /customers/{customer_id}/roles/{role_id}/grants | 
*CustomersApi* | [**list_roles**](docs/CustomersApi.md#list_roles) | **GET** /customers/{customer_id}/roles | 
*CustomersApi* | [**list_roles_on_cloudspace**](docs/CustomersApi.md#list_roles_on_cloudspace) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/granted-roles | 
*CustomersApi* | [**list_roles_on_customer**](docs/CustomersApi.md#list_roles_on_customer) | **GET** /customers/{customer_id}/granted-roles | 
*CustomersApi* | [**list_roles_on_location**](docs/CustomersApi.md#list_roles_on_location) | **GET** /customers/{customer_id}/locations/{location}/granted-roles | 
*CustomersApi* | [**list_roles_on_virtual_machine**](docs/CustomersApi.md#list_roles_on_virtual_machine) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/granted-roles | 
*CustomersApi* | [**list_virtual_machine_cdro_ms**](docs/CustomersApi.md#list_virtual_machine_cdro_ms) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/cdrom-images | 
*CustomersApi* | [**move_virtual_machine**](docs/CustomersApi.md#move_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/move | 
*CustomersApi* | [**pause_virtual_machine**](docs/CustomersApi.md#pause_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/pause | 
*CustomersApi* | [**read_file**](docs/CustomersApi.md#read_file) | **GET** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/file | 
*CustomersApi* | [**reboot_virtual_machine**](docs/CustomersApi.md#reboot_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/reboot | 
*CustomersApi* | [**recycle_bin**](docs/CustomersApi.md#recycle_bin) | **GET** /customers/{customer_id}/recycle-bin | 
*CustomersApi* | [**remove_cloudspace_external_network**](docs/CustomersApi.md#remove_cloudspace_external_network) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/external-network | 
*CustomersApi* | [**remove_cloudspace_network_route**](docs/CustomersApi.md#remove_cloudspace_network_route) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/routes | 
*CustomersApi* | [**remove_customer_location**](docs/CustomersApi.md#remove_customer_location) | **DELETE** /customers/{customer_id}/locations/{location} | 
*CustomersApi* | [**rename_cloudspace**](docs/CustomersApi.md#rename_cloudspace) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/name | 
*CustomersApi* | [**rename_virtual_machine**](docs/CustomersApi.md#rename_virtual_machine) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/name | 
*CustomersApi* | [**reset_bucket_limit**](docs/CustomersApi.md#reset_bucket_limit) | **PUT** /customers/{customer_id}/objectspaces/{objectspace_id}/{bucket_id}/reset-limit | 
*CustomersApi* | [**reset_objectspace**](docs/CustomersApi.md#reset_objectspace) | **PUT** /customers/{customer_id}/objectspaces/{objectspace_id}/reset | 
*CustomersApi* | [**reset_virtual_machine**](docs/CustomersApi.md#reset_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/reset | 
*CustomersApi* | [**resize_disk**](docs/CustomersApi.md#resize_disk) | **PUT** /customers/{customer_id}/locations/{location}/disks/{disk_id}/size | 
*CustomersApi* | [**resize_virtual_machine**](docs/CustomersApi.md#resize_virtual_machine) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/size | 
*CustomersApi* | [**restore_bucket**](docs/CustomersApi.md#restore_bucket) | **PUT** /customers/{customer_id}/objectspaces/{objectspace_id}/{bucket_id}/restore | 
*CustomersApi* | [**restore_cloudspace**](docs/CustomersApi.md#restore_cloudspace) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/restore | 
*CustomersApi* | [**restore_customer_cdrom_image**](docs/CustomersApi.md#restore_customer_cdrom_image) | **PUT** /customers/{customer_id}/locations/{location}/cdrom-images/{cdrom_id}/restore | 
*CustomersApi* | [**restore_customer_image**](docs/CustomersApi.md#restore_customer_image) | **PUT** /customers/{customer_id}/locations/{location}/vm-images/{image_id}/restore | 
*CustomersApi* | [**restore_disk**](docs/CustomersApi.md#restore_disk) | **PUT** /customers/{customer_id}/locations/{location}/disks/{disk_id}/restore | 
*CustomersApi* | [**restore_objectspace**](docs/CustomersApi.md#restore_objectspace) | **PUT** /customers/{customer_id}/objectspaces/{objectspace_id}/restore | 
*CustomersApi* | [**restore_virtual_machine**](docs/CustomersApi.md#restore_virtual_machine) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/restore | 
*CustomersApi* | [**resume_virtual_machine**](docs/CustomersApi.md#resume_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/resume | 
*CustomersApi* | [**rollback_disk_snapshot**](docs/CustomersApi.md#rollback_disk_snapshot) | **POST** /customers/{customer_id}/locations/{location}/disks/{disk_id}/snapshots/{snapshot_id}/rollback | 
*CustomersApi* | [**self_create_customer**](docs/CustomersApi.md#self_create_customer) | **POST** /customers/self-creation | 
*CustomersApi* | [**set_bucket_limit**](docs/CustomersApi.md#set_bucket_limit) | **PUT** /customers/{customer_id}/objectspaces/{objectspace_id}/{bucket_id}/bucket-limit | 
*CustomersApi* | [**set_cloudspace_default_gateway**](docs/CustomersApi.md#set_cloudspace_default_gateway) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/default-gateway | 
*CustomersApi* | [**set_cloudspace_proxy_config**](docs/CustomersApi.md#set_cloudspace_proxy_config) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/proxy-server | 
*CustomersApi* | [**set_disk_limit_io**](docs/CustomersApi.md#set_disk_limit_io) | **PUT** /customers/{customer_id}/locations/{location}/disks/{disk_id}/limitio | 
*CustomersApi* | [**start_virtual_machine**](docs/CustomersApi.md#start_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/start | 
*CustomersApi* | [**stop_virtual_machine**](docs/CustomersApi.md#stop_virtual_machine) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/stop | 
*CustomersApi* | [**take_disk_snapshot**](docs/CustomersApi.md#take_disk_snapshot) | **POST** /customers/{customer_id}/locations/{location}/disks/{disk_id}/snapshots | 
*CustomersApi* | [**unexpose_disk**](docs/CustomersApi.md#unexpose_disk) | **DELETE** /customers/{customer_id}/cloudspaces/{cloudspace_id}/exposed-disks/{disk_id} | 
*CustomersApi* | [**upate_objectspace_note**](docs/CustomersApi.md#upate_objectspace_note) | **PUT** /customers/{customer_id}/objectspaces/{objectspace_id}/notes/{note_id} | 
*CustomersApi* | [**update_certificate**](docs/CustomersApi.md#update_certificate) | **PUT** /customers/{customer_id}/certificates/ssl/{domain} | 
*CustomersApi* | [**update_cloudspace_anti_affinity_group**](docs/CustomersApi.md#update_cloudspace_anti_affinity_group) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/anti-affinity-groups/{group_id} | 
*CustomersApi* | [**update_cloudspace_external_network_metric**](docs/CustomersApi.md#update_cloudspace_external_network_metric) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/external-network | 
*CustomersApi* | [**update_cloudspace_note**](docs/CustomersApi.md#update_cloudspace_note) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/notes/{note_id} | 
*CustomersApi* | [**update_cloudspace_quota**](docs/CustomersApi.md#update_cloudspace_quota) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/quota | 
*CustomersApi* | [**update_customer**](docs/CustomersApi.md#update_customer) | **PUT** /customers/{customer_id} | 
*CustomersApi* | [**update_disk_model**](docs/CustomersApi.md#update_disk_model) | **PUT** /customers/{customer_id}/locations/{location}/disks/{disk_id}/model | 
*CustomersApi* | [**update_disk_note**](docs/CustomersApi.md#update_disk_note) | **PUT** /customers/{customer_id}/locations/{location}/disks/{disk_id}/notes/{note_id} | 
*CustomersApi* | [**update_network_interface_model**](docs/CustomersApi.md#update_network_interface_model) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/network-interfaces/{mac_address}/model | 
*CustomersApi* | [**update_portforward**](docs/CustomersApi.md#update_portforward) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/portforwards/{portforward_id} | 
*CustomersApi* | [**update_role**](docs/CustomersApi.md#update_role) | **PUT** /customers/{customer_id}/roles/{role_id} | 
*CustomersApi* | [**update_role_grants**](docs/CustomersApi.md#update_role_grants) | **PUT** /customers/{customer_id}/roles/{role_id}/grants | 
*CustomersApi* | [**update_virtual_machine_description**](docs/CustomersApi.md#update_virtual_machine_description) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/description | 
*CustomersApi* | [**update_virtual_machine_note**](docs/CustomersApi.md#update_virtual_machine_note) | **PUT** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/notes/{note_id} | 
*CustomersApi* | [**write_file**](docs/CustomersApi.md#write_file) | **POST** /customers/{customer_id}/cloudspaces/{cloudspace_id}/vms/{vm_id}/file | 
*LocationsApi* | [**get_location_datacenter**](docs/LocationsApi.md#get_location_datacenter) | **GET** /locations/{location}/datacenter | 
*LocationsApi* | [**list_locations**](docs/LocationsApi.md#list_locations) | **GET** /locations | 
*LogsApi* | [**log_ui_error**](docs/LogsApi.md#log_ui_error) | **POST** /logs | 
*MeApi* | [**get_current_user_info**](docs/MeApi.md#get_current_user_info) | **GET** /me | 
*MeApi* | [**get_current_user_jwt**](docs/MeApi.md#get_current_user_jwt) | **GET** /me/jwt | 
*MeApi* | [**get_email_subscriptions**](docs/MeApi.md#get_email_subscriptions) | **GET** /me/email-subscriptions | 
*MeApi* | [**get_new_email_subscriptions**](docs/MeApi.md#get_new_email_subscriptions) | **GET** /me/new-email-subscriptions | 
*MeApi* | [**list_user_notifications**](docs/MeApi.md#list_user_notifications) | **GET** /me/email-notifications | 
*MeApi* | [**update_email_subscription**](docs/MeApi.md#update_email_subscription) | **PUT** /me/email-subscriptions | 
*UtilitiesApi* | [**download_csi_driver_examples**](docs/UtilitiesApi.md#download_csi_driver_examples) | **GET** /utilities/csi-driver/examples | 
*UtilitiesApi* | [**download_kubernetes_configuration_files_example**](docs/UtilitiesApi.md#download_kubernetes_configuration_files_example) | **GET** /utilities/examples/kubernetes-files | 
*UtilitiesApi* | [**download_terraform_provider_version**](docs/UtilitiesApi.md#download_terraform_provider_version) | **GET** /utilities/terraform-provider/version | 
*UtilitiesApi* | [**get_cli**](docs/UtilitiesApi.md#get_cli) | **GET** /utilities/cli | 
*UtilitiesApi* | [**get_latest_cli_version_info**](docs/UtilitiesApi.md#get_latest_cli_version_info) | **GET** /utilities/cli/version | 
*UtilitiesApi* | [**get_terrafom_provider**](docs/UtilitiesApi.md#get_terrafom_provider) | **GET** /utilities/terraform-provider | 
*UtilitiesApi* | [**list_cli_platforms**](docs/UtilitiesApi.md#list_cli_platforms) | **GET** /utilities/cli/platforms | 
*UtilitiesApi* | [**list_terraform_provider_platforms**](docs/UtilitiesApi.md#list_terraform_provider_platforms) | **GET** /utilities/terrafrom-provider/platforms | 


## Documentation For Models

 - [AccountConsumptionModel](docs/AccountConsumptionModel.md)
 - [AccountConsumptionModelCloudspaces](docs/AccountConsumptionModelCloudspaces.md)
 - [AccountConsumptionModelCloudspacesConsumption](docs/AccountConsumptionModelCloudspacesConsumption.md)
 - [AccountConsumptionModelCloudspacesVms](docs/AccountConsumptionModelCloudspacesVms.md)
 - [AccountConsumptionModelCloudspacesVmsConsumption](docs/AccountConsumptionModelCloudspacesVmsConsumption.md)
 - [AccountConsumptionModelConsumption](docs/AccountConsumptionModelConsumption.md)
 - [AccountConsumptionModelObjectspaces](docs/AccountConsumptionModelObjectspaces.md)
 - [AccountConsumptionModelObjectspacesConsumption](docs/AccountConsumptionModelObjectspacesConsumption.md)
 - [AccountConsumptionModelUnassignedDisks](docs/AccountConsumptionModelUnassignedDisks.md)
 - [AccountConsumptionModelUnassignedDisksConsumption](docs/AccountConsumptionModelUnassignedDisksConsumption.md)
 - [AccountConsumptionTsModel](docs/AccountConsumptionTsModel.md)
 - [AccountConsumptionTsModelCloudspaces](docs/AccountConsumptionTsModelCloudspaces.md)
 - [AccountConsumptionTsModelCloudspacesConsumption](docs/AccountConsumptionTsModelCloudspacesConsumption.md)
 - [AccountConsumptionTsModelCloudspacesConsumptionData](docs/AccountConsumptionTsModelCloudspacesConsumptionData.md)
 - [AccountConsumptionTsModelCloudspacesVms](docs/AccountConsumptionTsModelCloudspacesVms.md)
 - [AccountConsumptionTsModelCloudspacesVmsConsumption](docs/AccountConsumptionTsModelCloudspacesVmsConsumption.md)
 - [AccountConsumptionTsModelCloudspacesVmsConsumptionData](docs/AccountConsumptionTsModelCloudspacesVmsConsumptionData.md)
 - [AccountConsumptionTsModelConsumption](docs/AccountConsumptionTsModelConsumption.md)
 - [AccountConsumptionTsModelConsumptionData](docs/AccountConsumptionTsModelConsumptionData.md)
 - [AccountConsumptionTsModelObjectspaces](docs/AccountConsumptionTsModelObjectspaces.md)
 - [AccountConsumptionTsModelObjectspacesBuckets](docs/AccountConsumptionTsModelObjectspacesBuckets.md)
 - [AccountConsumptionTsModelObjectspacesBucketsConsumption](docs/AccountConsumptionTsModelObjectspacesBucketsConsumption.md)
 - [AccountConsumptionTsModelObjectspacesBucketsConsumptionData](docs/AccountConsumptionTsModelObjectspacesBucketsConsumptionData.md)
 - [AccountConsumptionTsModelObjectspacesConsumption](docs/AccountConsumptionTsModelObjectspacesConsumption.md)
 - [AccountConsumptionTsModelObjectspacesConsumptionData](docs/AccountConsumptionTsModelObjectspacesConsumptionData.md)
 - [AccountConsumptionTsModelUnassignedDisks](docs/AccountConsumptionTsModelUnassignedDisks.md)
 - [AccountConsumptionTsModelUnassignedDisksConsumption](docs/AccountConsumptionTsModelUnassignedDisksConsumption.md)
 - [AccountConsumptionTsModelUnassignedDisksConsumptionData](docs/AccountConsumptionTsModelUnassignedDisksConsumptionData.md)
 - [AddProxyConfig](docs/AddProxyConfig.md)
 - [AddProxyInput](docs/AddProxyInput.md)
 - [AntiAffinityGroups](docs/AntiAffinityGroups.md)
 - [Buckets](docs/Buckets.md)
 - [CDROMIdModel](docs/CDROMIdModel.md)
 - [CDROMModel](docs/CDROMModel.md)
 - [CDROMs](docs/CDROMs.md)
 - [CapacityModel](docs/CapacityModel.md)
 - [CdromImagesModel](docs/CdromImagesModel.md)
 - [Certificate](docs/Certificate.md)
 - [CertificateChain](docs/CertificateChain.md)
 - [Certificates](docs/Certificates.md)
 - [CertificatesSimple](docs/CertificatesSimple.md)
 - [ChangeAgentStatus](docs/ChangeAgentStatus.md)
 - [ChangedModel](docs/ChangedModel.md)
 - [ChatConfig](docs/ChatConfig.md)
 - [CloneDiskSnapshot](docs/CloneDiskSnapshot.md)
 - [ClonedDisk](docs/ClonedDisk.md)
 - [CloudspaceChild](docs/CloudspaceChild.md)
 - [CloudspaceChildren](docs/CloudspaceChildren.md)
 - [CloudspaceConsumption](docs/CloudspaceConsumption.md)
 - [CloudspaceConsumptionModel](docs/CloudspaceConsumptionModel.md)
 - [CloudspaceConsumptionModelCloudspace](docs/CloudspaceConsumptionModelCloudspace.md)
 - [CloudspaceConsumptionModelCloudspaceConsumption](docs/CloudspaceConsumptionModelCloudspaceConsumption.md)
 - [CloudspaceConsumptionModelCloudspaceVms](docs/CloudspaceConsumptionModelCloudspaceVms.md)
 - [CloudspaceConsumptionModelCloudspaceVmsConsumption](docs/CloudspaceConsumptionModelCloudspaceVmsConsumption.md)
 - [CloudspaceConsumptionTsModel](docs/CloudspaceConsumptionTsModel.md)
 - [CloudspaceConsumptionTsModelCloudspace](docs/CloudspaceConsumptionTsModelCloudspace.md)
 - [CloudspaceConsumptionTsModelCloudspaceConsumption](docs/CloudspaceConsumptionTsModelCloudspaceConsumption.md)
 - [CloudspaceConsumptionTsModelCloudspaceConsumptionData](docs/CloudspaceConsumptionTsModelCloudspaceConsumptionData.md)
 - [CloudspaceConsumptionTsModelCloudspaceVms](docs/CloudspaceConsumptionTsModelCloudspaceVms.md)
 - [CloudspaceConsumptionTsModelCloudspaceVmsConsumption](docs/CloudspaceConsumptionTsModelCloudspaceVmsConsumption.md)
 - [CloudspaceConsumptionTsModelCloudspaceVmsConsumptionData](docs/CloudspaceConsumptionTsModelCloudspaceVmsConsumptionData.md)
 - [CloudspaceIDModel](docs/CloudspaceIDModel.md)
 - [CloudspaceInfoModel](docs/CloudspaceInfoModel.md)
 - [CloudspaceInfoModelResourceLimits](docs/CloudspaceInfoModelResourceLimits.md)
 - [CloudspaceProxyConfigModel](docs/CloudspaceProxyConfigModel.md)
 - [CloudspaceProxyConfigModelConfig](docs/CloudspaceProxyConfigModelConfig.md)
 - [CloudspaceStatsModel](docs/CloudspaceStatsModel.md)
 - [CloudspaceStatsModelSeries](docs/CloudspaceStatsModelSeries.md)
 - [CloudspaceStatsModelSeriesCpu](docs/CloudspaceStatsModelSeriesCpu.md)
 - [CloudspaceStatsModelSeriesNetwork](docs/CloudspaceStatsModelSeriesNetwork.md)
 - [CloudspaceStatsModelSeriesNetworkGateways](docs/CloudspaceStatsModelSeriesNetworkGateways.md)
 - [CloudspaceStatsModelSeriesNetworkVms](docs/CloudspaceStatsModelSeriesNetworkVms.md)
 - [Cloudspaces](docs/Cloudspaces.md)
 - [CloudspacesModel](docs/CloudspacesModel.md)
 - [ColorScheme](docs/ColorScheme.md)
 - [ConnectedCloudspace](docs/ConnectedCloudspace.md)
 - [ConnectedCloudspaces](docs/ConnectedCloudspaces.md)
 - [Consumption](docs/Consumption.md)
 - [Coordinates](docs/Coordinates.md)
 - [CreateCloudspace](docs/CreateCloudspace.md)
 - [CreateCloudspaceFirewall](docs/CreateCloudspaceFirewall.md)
 - [CreateCustomerCertificate](docs/CreateCustomerCertificate.md)
 - [CreateLoadBalancerBackEnd](docs/CreateLoadBalancerBackEnd.md)
 - [CreateLoadBalancerFull](docs/CreateLoadBalancerFull.md)
 - [CreateObjectspaceModel](docs/CreateObjectspaceModel.md)
 - [CreateReverseProxyBackEnd](docs/CreateReverseProxyBackEnd.md)
 - [CreateReverseProxyFull](docs/CreateReverseProxyFull.md)
 - [CreateTemplateModel](docs/CreateTemplateModel.md)
 - [CustomCloudspaceFirewall](docs/CustomCloudspaceFirewall.md)
 - [Customer](docs/Customer.md)
 - [CustomerBillingInformation](docs/CustomerBillingInformation.md)
 - [CustomerCompanyInformation](docs/CustomerCompanyInformation.md)
 - [CustomerComplianceReport](docs/CustomerComplianceReport.md)
 - [CustomerComplianceSeries](docs/CustomerComplianceSeries.md)
 - [CustomerContactInformation](docs/CustomerContactInformation.md)
 - [CustomerCoordinates](docs/CustomerCoordinates.md)
 - [CustomerCreate](docs/CustomerCreate.md)
 - [CustomerCreateBillingInformation](docs/CustomerCreateBillingInformation.md)
 - [CustomerCreateCompanyInformation](docs/CustomerCreateCompanyInformation.md)
 - [CustomerCreateContactInformation](docs/CustomerCreateContactInformation.md)
 - [CustomerCreateCoordinates](docs/CustomerCreateCoordinates.md)
 - [CustomerInvoice](docs/CustomerInvoice.md)
 - [CustomerInvoiceList](docs/CustomerInvoiceList.md)
 - [CustomerRole](docs/CustomerRole.md)
 - [CustomerRoleCreate](docs/CustomerRoleCreate.md)
 - [CustomerRoleCreateRolePermissions](docs/CustomerRoleCreateRolePermissions.md)
 - [CustomerRoleFull](docs/CustomerRoleFull.md)
 - [CustomerRoleFullRolePermissions](docs/CustomerRoleFullRolePermissions.md)
 - [CustomerRoleList](docs/CustomerRoleList.md)
 - [CustomerRoleResource](docs/CustomerRoleResource.md)
 - [CustomerRoleResourceGrant](docs/CustomerRoleResourceGrant.md)
 - [CustomerRoleResources](docs/CustomerRoleResources.md)
 - [CustomerRoleRolePermissions](docs/CustomerRoleRolePermissions.md)
 - [CustomerSelfCreate](docs/CustomerSelfCreate.md)
 - [CustomerSelfCreateBillingInformation](docs/CustomerSelfCreateBillingInformation.md)
 - [CustomerSelfCreateCompanyInformation](docs/CustomerSelfCreateCompanyInformation.md)
 - [CustomerSelfCreateContactInformation](docs/CustomerSelfCreateContactInformation.md)
 - [CustomerSimple](docs/CustomerSimple.md)
 - [CustomerUpdate](docs/CustomerUpdate.md)
 - [CustomerUpdateBillingInformation](docs/CustomerUpdateBillingInformation.md)
 - [CustomerUpdateCompanyInformation](docs/CustomerUpdateCompanyInformation.md)
 - [CustomerUpdateContactInformation](docs/CustomerUpdateContactInformation.md)
 - [CustomerUpdateCoordinates](docs/CustomerUpdateCoordinates.md)
 - [CustomersSimple](docs/CustomersSimple.md)
 - [Datacenter](docs/Datacenter.md)
 - [DefaultGateway](docs/DefaultGateway.md)
 - [DeletedBucket](docs/DeletedBucket.md)
 - [DeletedCDROM](docs/DeletedCDROM.md)
 - [DeletedCloudspace](docs/DeletedCloudspace.md)
 - [DeletedDisk](docs/DeletedDisk.md)
 - [DeletedImage](docs/DeletedImage.md)
 - [DeletedMachine](docs/DeletedMachine.md)
 - [DeletedObjectspace](docs/DeletedObjectspace.md)
 - [DeletedResources](docs/DeletedResources.md)
 - [DiskConsumption](docs/DiskConsumption.md)
 - [DiskConsumptionModel](docs/DiskConsumptionModel.md)
 - [DiskConsumptionTsModel](docs/DiskConsumptionTsModel.md)
 - [DiskConsumptionTsModelData](docs/DiskConsumptionTsModelData.md)
 - [DiskIdModel](docs/DiskIdModel.md)
 - [DiskModel](docs/DiskModel.md)
 - [DiskModelIotune](docs/DiskModelIotune.md)
 - [DiskSnapshotModel](docs/DiskSnapshotModel.md)
 - [DiskTimeseries](docs/DiskTimeseries.md)
 - [Disks](docs/Disks.md)
 - [DisksModel](docs/DisksModel.md)
 - [DisksModelIotune](docs/DisksModelIotune.md)
 - [ExpectedSequenceNumber](docs/ExpectedSequenceNumber.md)
 - [ExposeDiskModel](docs/ExposeDiskModel.md)
 - [ExposeDiskModelEndpoint](docs/ExposeDiskModelEndpoint.md)
 - [ExposedDisks](docs/ExposedDisks.md)
 - [ExternalNIC](docs/ExternalNIC.md)
 - [ExternalNICModels](docs/ExternalNICModels.md)
 - [ExternalNICS](docs/ExternalNICS.md)
 - [ExternalNICSElement](docs/ExternalNICSElement.md)
 - [ExternalNetworkModel](docs/ExternalNetworkModel.md)
 - [ExternalNetworks](docs/ExternalNetworks.md)
 - [ExternalNetworksModel](docs/ExternalNetworksModel.md)
 - [GetAgentStatus](docs/GetAgentStatus.md)
 - [GetBucketModel](docs/GetBucketModel.md)
 - [GetCloudspaceAntiAffinityGroupModel](docs/GetCloudspaceAntiAffinityGroupModel.md)
 - [GetCloudspaceAntiAffinityGroupVmsModel](docs/GetCloudspaceAntiAffinityGroupVmsModel.md)
 - [GetCloudspaceAntiAffinityGroupVmsModelVms](docs/GetCloudspaceAntiAffinityGroupVmsModelVms.md)
 - [GetObjectspaceListModel](docs/GetObjectspaceListModel.md)
 - [GetObjectspaceListModelCloudspaces](docs/GetObjectspaceListModelCloudspaces.md)
 - [GetObjectspaceModel](docs/GetObjectspaceModel.md)
 - [GetObjectspaceModelCloudspaces](docs/GetObjectspaceModelCloudspaces.md)
 - [GetObjectspaceModelLimits](docs/GetObjectspaceModelLimits.md)
 - [IDModel](docs/IDModel.md)
 - [ImageID](docs/ImageID.md)
 - [ImageModel](docs/ImageModel.md)
 - [ImageModelCapabilities](docs/ImageModelCapabilities.md)
 - [Images](docs/Images.md)
 - [ImagesModel](docs/ImagesModel.md)
 - [IngressConfig](docs/IngressConfig.md)
 - [InvoiceLegalTerms](docs/InvoiceLegalTerms.md)
 - [InvoiceLine](docs/InvoiceLine.md)
 - [InvoiceModel](docs/InvoiceModel.md)
 - [InvoiceNumberingFormat](docs/InvoiceNumberingFormat.md)
 - [InvoicePaymentTerms](docs/InvoicePaymentTerms.md)
 - [InvoicesModel](docs/InvoicesModel.md)
 - [LegalDocumentVersion](docs/LegalDocumentVersion.md)
 - [LegalDocumentVersions](docs/LegalDocumentVersions.md)
 - [LetsEncrypt](docs/LetsEncrypt.md)
 - [ListBucketsModel](docs/ListBucketsModel.md)
 - [ListCloudspaceAntiAffinityGroupsModel](docs/ListCloudspaceAntiAffinityGroupsModel.md)
 - [LoadBalanceFrontEnd](docs/LoadBalanceFrontEnd.md)
 - [LoadBalancerList](docs/LoadBalancerList.md)
 - [LoadBalancerSimple](docs/LoadBalancerSimple.md)
 - [LoadBalancerTLS](docs/LoadBalancerTLS.md)
 - [Location](docs/Location.md)
 - [LocationPricing](docs/LocationPricing.md)
 - [LocationPricingResourcePrices](docs/LocationPricingResourcePrices.md)
 - [LocationSimple](docs/LocationSimple.md)
 - [LocationStatus](docs/LocationStatus.md)
 - [LocationsModel](docs/LocationsModel.md)
 - [MenejaStructsNotificationSubscriptionDataclassesMaintenanceStatusStruct](docs/MenejaStructsNotificationSubscriptionDataclassesMaintenanceStatusStruct.md)
 - [MenejaStructsNotificationSubscriptionDataclassesNotificationTypeStruct](docs/MenejaStructsNotificationSubscriptionDataclassesNotificationTypeStruct.md)
 - [MenejaStructsNotificationSubscriptionDataclassesNotificationTypesStruct](docs/MenejaStructsNotificationSubscriptionDataclassesNotificationTypesStruct.md)
 - [MenejaStructsNotificationSubscriptionDataclassesNotificationUtilitiesStruct](docs/MenejaStructsNotificationSubscriptionDataclassesNotificationUtilitiesStruct.md)
 - [MenejaStructsNotificationSubscriptionDataclassesNotificationsForwardingStruct](docs/MenejaStructsNotificationSubscriptionDataclassesNotificationsForwardingStruct.md)
 - [MenejaStructsNotificationSubscriptionDataclassesServiceImpactStruct](docs/MenejaStructsNotificationSubscriptionDataclassesServiceImpactStruct.md)
 - [MenejaStructsNotificationSubscriptionDataclassesTestEmailStruct](docs/MenejaStructsNotificationSubscriptionDataclassesTestEmailStruct.md)
 - [MenejaStructsNotificationSubscriptionDataclassesTestEmailsStruct](docs/MenejaStructsNotificationSubscriptionDataclassesTestEmailsStruct.md)
 - [MenejaStructsNotificationSubscriptionDataclassesTimezoneStruct](docs/MenejaStructsNotificationSubscriptionDataclassesTimezoneStruct.md)
 - [MenejaStructsVcoDataclassesDemoUserDemoUserStruct](docs/MenejaStructsVcoDataclassesDemoUserDemoUserStruct.md)
 - [MenejaStructsVcoDataclassesNotesNoteInputsStruct](docs/MenejaStructsVcoDataclassesNotesNoteInputsStruct.md)
 - [MenejaStructsVcoDataclassesNotesResourceNoteStruct](docs/MenejaStructsVcoDataclassesNotesResourceNoteStruct.md)
 - [MenejaStructsVcoDataclassesSnapshotSnapshotStruct](docs/MenejaStructsVcoDataclassesSnapshotSnapshotStruct.md)
 - [MenejaStructsVcoDataclassesVcoCustomerComplianceStruct](docs/MenejaStructsVcoDataclassesVcoCustomerComplianceStruct.md)
 - [MenejaStructsVcoDataclassesVmVMWriteFileStruct](docs/MenejaStructsVcoDataclassesVmVMWriteFileStruct.md)
 - [NamingInfo](docs/NamingInfo.md)
 - [NonCompliantCloudSpace](docs/NonCompliantCloudSpace.md)
 - [NonCompliantMachine](docs/NonCompliantMachine.md)
 - [NotificationConfig](docs/NotificationConfig.md)
 - [NotificationConfigNotificationLocation](docs/NotificationConfigNotificationLocation.md)
 - [OSNamesMap](docs/OSNamesMap.md)
 - [OSTypeName](docs/OSTypeName.md)
 - [ObjectSpace](docs/ObjectSpace.md)
 - [ObjectSpaces](docs/ObjectSpaces.md)
 - [ObjectspaceConsumption](docs/ObjectspaceConsumption.md)
 - [ObjectspacesForCloudspace](docs/ObjectspacesForCloudspace.md)
 - [PortforwardID](docs/PortforwardID.md)
 - [Portforwards](docs/Portforwards.md)
 - [PortforwardsModel](docs/PortforwardsModel.md)
 - [PricesWithCurrency](docs/PricesWithCurrency.md)
 - [RecycleBin](docs/RecycleBin.md)
 - [RemoteConnectionStatus](docs/RemoteConnectionStatus.md)
 - [ResetObjectspaceModel](docs/ResetObjectspaceModel.md)
 - [ResourceConsumption](docs/ResourceConsumption.md)
 - [ResourceNotes](docs/ResourceNotes.md)
 - [ResourcePrices](docs/ResourcePrices.md)
 - [ReverseProxyBackEndHealthCheck](docs/ReverseProxyBackEndHealthCheck.md)
 - [ReverseProxyBackEndOptions](docs/ReverseProxyBackEndOptions.md)
 - [ReverseProxyBackEndStickCookie](docs/ReverseProxyBackEndStickCookie.md)
 - [ReverseProxyFrontEnd](docs/ReverseProxyFrontEnd.md)
 - [ReverseProxyList](docs/ReverseProxyList.md)
 - [ReverseProxySimple](docs/ReverseProxySimple.md)
 - [ServerPool](docs/ServerPool.md)
 - [ServerPoolHost](docs/ServerPoolHost.md)
 - [ServerPoolHosts](docs/ServerPoolHosts.md)
 - [ServerPoolList](docs/ServerPoolList.md)
 - [ServerPoolSimple](docs/ServerPoolSimple.md)
 - [ShowLoadBalancerBackEnd](docs/ShowLoadBalancerBackEnd.md)
 - [ShowLoadBalancerFull](docs/ShowLoadBalancerFull.md)
 - [ShowReverseProxyBackEnd](docs/ShowReverseProxyBackEnd.md)
 - [ShowReverseProxyFull](docs/ShowReverseProxyFull.md)
 - [SnapshotDisks](docs/SnapshotDisks.md)
 - [Snapshots](docs/Snapshots.md)
 - [SuccessModel](docs/SuccessModel.md)
 - [SupportedPlatforms](docs/SupportedPlatforms.md)
 - [UIErrorLog](docs/UIErrorLog.md)
 - [UnitPrices](docs/UnitPrices.md)
 - [User](docs/User.md)
 - [UserCustomer](docs/UserCustomer.md)
 - [UserEmailSubscriptionConfigEmailPreferences](docs/UserEmailSubscriptionConfigEmailPreferences.md)
 - [UserEmailSubscriptionConfigLocationNotificationTypes](docs/UserEmailSubscriptionConfigLocationNotificationTypes.md)
 - [UserEmailSubscriptionConfigNonLocationNotificationTypes](docs/UserEmailSubscriptionConfigNonLocationNotificationTypes.md)
 - [UserEmailSubscriptionConfigNotificationPreferencesLocation](docs/UserEmailSubscriptionConfigNotificationPreferencesLocation.md)
 - [VCOComplianceReport](docs/VCOComplianceReport.md)
 - [VCOSettings](docs/VCOSettings.md)
 - [VMConsumption](docs/VMConsumption.md)
 - [VMCreateExtentions](docs/VMCreateExtentions.md)
 - [VMExecuteModel](docs/VMExecuteModel.md)
 - [VMPrice](docs/VMPrice.md)
 - [VcoPricing](docs/VcoPricing.md)
 - [VcoPricingFlagged](docs/VcoPricingFlagged.md)
 - [VcoPricingFlaggedLocationPrices](docs/VcoPricingFlaggedLocationPrices.md)
 - [VcoPricingFlaggedResourcePrices](docs/VcoPricingFlaggedResourcePrices.md)
 - [VcoPricingLocationPrices](docs/VcoPricingLocationPrices.md)
 - [VcoPricingResourcePrices](docs/VcoPricingResourcePrices.md)
 - [VersionInfo](docs/VersionInfo.md)
 - [VirtualMachineDisks](docs/VirtualMachineDisks.md)
 - [VirtualMachines](docs/VirtualMachines.md)
 - [VmCommandModel](docs/VmCommandModel.md)
 - [VmConsumptionModel](docs/VmConsumptionModel.md)
 - [VmConsumptionModelVm](docs/VmConsumptionModelVm.md)
 - [VmConsumptionModelVmConsumption](docs/VmConsumptionModelVmConsumption.md)
 - [VmConsumptionTsModel](docs/VmConsumptionTsModel.md)
 - [VmConsumptionTsModelVm](docs/VmConsumptionTsModelVm.md)
 - [VmConsumptionTsModelVmData](docs/VmConsumptionTsModelVmData.md)
 - [VmIdModel](docs/VmIdModel.md)
 - [VmInfoModel](docs/VmInfoModel.md)
 - [VmInfoModelDisks](docs/VmInfoModelDisks.md)
 - [VmInfoModelNetworkInterfaces](docs/VmInfoModelNetworkInterfaces.md)
 - [VmInfoModelOsAccounts](docs/VmInfoModelOsAccounts.md)
 - [VmReadFileModel](docs/VmReadFileModel.md)
 - [VmStatsModel](docs/VmStatsModel.md)
 - [VmStatsModelSeries](docs/VmStatsModelSeries.md)
 - [VmStatsModelSeriesNetwork](docs/VmStatsModelSeriesNetwork.md)
 - [VmStatsModelSeriesNetworkUsage](docs/VmStatsModelSeriesNetworkUsage.md)
 - [VmStatsModelSeriesVdiskBandwidth](docs/VmStatsModelSeriesVdiskBandwidth.md)
 - [VmStatsModelSeriesVdiskCapacity](docs/VmStatsModelSeriesVdiskCapacity.md)
 - [VmStatsModelSeriesVdiskIops](docs/VmStatsModelSeriesVdiskIops.md)
 - [VmStatsModelSeriesVdiskLatency](docs/VmStatsModelSeriesVdiskLatency.md)
 - [VmsModel](docs/VmsModel.md)
 - [VmsModelNetworkInterfaces](docs/VmsModelNetworkInterfaces.md)


## Documentation For Authorization


## Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author



